Description Usage Arguments Value Examples
Plot a transparent half pitch for an understat shotmap.
1 | pitch_us(filler = "#2f4f4f")
|
filler |
the colour you want your pitch lines to be. there is no background colour option, please use plot.background and panel.background. this is so the pitch can be plotted over heatmaps. |
a ggplot annotation half pitch.
1 2 3 4 5 6 7 8 9 10 11 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.